import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
   A class that demonstrates a correct way to center a
   graphic string in a container.  The container calculates
   its size based on the length of the string text and the
   font metrics of the font used to display the text.

   <p>Arbitrarily, the program decides to size the container
   so that there are 50 pixels to the left and right of the
   ends of the string, and 70 pixels above and below the
   string.
*/
class FontMetricsDemo extends JPanel
{
  /**
     No-arg constructor.  Chooses an arbitrary font and
     string to demonstrate the dynamic calculation of the
     container.
  */
  public FontMetricsDemo()
  {
    // Use this font to draw the string text.
    //
    f = new Font("Dialog", Font.PLAIN, 18);

    // Draw the graphics representing this string.
    //
    message = new String("How much space does this text use?");
  }


  /**
     Paints this component.  Notice that this class
     overrides <code>paintComponent()</code> and
     <em>not</em> <code>paint()</code> because it is a
     subclass of a Swing component.
  */
  public void paintComponent(Graphics g)
  {
    super.paintComponent(g);

    // Center the message in the container with padding on
    // each side as follows: 50 pixels from the left and
    // right sides, and 70 pixels from the top and bottom.
    // See the getPreferredSize() method.
    // 
    g.setFont(f);
    g.drawString(message, 50, 70);
  }


  /**
     Return the preferred size of this component suitable
     for one particular string.

     @return the preferred size needed to center the string text.
  */
  public Dimension getPreferredSize()
  {
    // Get the font metrics for the font we want to use.
    //
    FontMetrics fm = getFontMetrics(f);

    // Determine the total advance width for the whole
    // string.  The container must be this width plus the
    // padding between the ends of the string and the left
    // and right edges of the container.
    //
    int width = fm.stringWidth(message) + 2 * 50;

    int height = fm.getMaxAscent() + 2 * 70;
    
    return new Dimension(width, height);
  }


  Font f;

  String message;


  public static void main(String [] args)
  {
    FontMetricsDemo app = new FontMetricsDemo();
    JFrame f = new JFrame("Graphics Positioning Demo ");
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    e.getWindow().dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);
    f.getContentPane().add(app);
    f.pack();
    f.show();
  }
}
