import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.Window;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JRootPane;
import javax.swing.JTextField;

/**
   A class that demonstrates adding some components to a Swing
   container.  This class defines a container that is a subclass of
   java.awt.Frame.
*/
class FrameWithComponents extends JFrame
{
  /**
     No-arg constructor.  
  */
  public FrameWithComponents()
  {
    super("A Swing frame with some components");

    // The root pane holds a reference to the content pane of the
    // Swing heavyweight containers. You can also get the content
    // pane directly by calling the convenience method
    // getContentPane().
    //
    JRootPane rootPane = getRootPane();
    Container contentPane = rootPane.getContentPane();

    // Must set the layout manager on the container's
    // content pane, not the container itself.
    //
    contentPane.setLayout(new FlowLayout());

    Font font14 = new Font("SansSerif", Font.PLAIN, 14);
    Font font18 = new Font("SansSerif", Font.PLAIN, 18);

    label = new JLabel("A simple label in a frame");
    label.setFont(font18);

    // Add the label to the content pane of the JFrame, not to the
    // JFrame directly.
    //
    contentPane.add(label);

    button = new JButton("Push me");
    button.setFont(font14);

    textField = new JTextField("A text field");
    textField.setFont(font14);

    String [] strings =
    { "Button", "Canvas", "Checkbox", "Label",
      "List", "Scrollbar", "ScrollPane", 
      "TextField", "TextArea" 
    };
    list = new JList(strings);
    list.setVisibleRowCount(7);
    list.setFont(font14);

    // Also add the these three components to the frame's content
    // pane.
    //
    contentPane.add(button);
    contentPane.add(textField);
    contentPane.add(list);
  }

  public Dimension getPreferredSize()
  {
    return new Dimension(300, 300);
  }

  public static void main(String [] args)
  {
    FrameWithComponents f = new FrameWithComponents();
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    f.pack();
    f.setVisible(true);
  }

  JButton button;
  JTextField textField;
  JLabel label;
  JList list;
  
}
