import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;

/**

   This class demonstrates use of Swing menus.  Menus in Swing are
   organized differently than AWT menus in the component hierarchy.
*/
public class Menus extends JFrame
{
  /**
     No-arg constructor.
  */
  public Menus()
  {
    super("Menus Demo");

    Container contentPane = getContentPane();

    Font f14 = new Font("SansSerif", Font.PLAIN, 14);
    Dimension dim = new Dimension(0, 10);

    // Create the menu "Menu 1", which is the leftmost menu on the
    // menubar.
    //
    JMenu menu1 = new JMenu("Menu 1");

    // Create the menu items that are part of "Menu 1".
    //
    JMenuItem mi1 = new JMenuItem("Menu Item 1");
    mi1.setMnemonic('1');
    JMenuItem mi2 = new JMenuItem("Menu Item 2");
    mi2.setMnemonic('2');
    JMenuItem mi3 = new JMenuItem("Menu Item 3");
    mi3.setMnemonic('3');

    // Create the sub-menu "Nested Menu" that is the last item of
    // the "Menu 1" menu.
    //
    JMenu menu1_1 = new JMenu("Nested Menu");

    // Create the menu items for the "Nested Menu" menu.
    //
    JMenuItem mi1_1 = new JMenuItem("15 Love");
    mi1_1.setHorizontalAlignment(SwingConstants.LEFT);
    JMenuItem mi1_2 = new JMenuItem("30 Love");
    JMenuItem mi1_3 = new JMenuItem("40 Love");
    JMenuItem mi1_4 = new JMenuItem("Game");
    
    // Add the "Nested Menu" menu items to the "Nested Menu".
    //
    menu1_1.add(mi1_1);
    menu1_1.add(mi1_2);
    menu1_1.add(mi1_3);
    menu1_1.add(mi1_4);

    // Add the first three menu items to the "Menu 1" menu.  Then add
    // a separator to separate the nested menu.  Finally, add the
    // "Nested Menu" last.
    //
    menu1.add(mi1);
    menu1.add(mi2);
    menu1.add(mi3);
    menu1.addSeparator();
    menu1.add(menu1_1);

    // Create the second and third menus, "Menu 2" and "Menu 3", which
    // are placed to the right of "Menu 1" on the menu bar.
    //
    JMenu menu2 = new JMenu("Menu 2");
    JMenu menu3 = new JMenu("Menu 3");

    // --------

    // code below here is for Listing 7.9 and Fig 7.15.

    // --------

    // Create the first set of menu items for "Menu 2".  The first
    // items are check boxes.
    //
    JCheckBoxMenuItem cbmi1 = new JCheckBoxMenuItem("Check box 1");
    JCheckBoxMenuItem cbmi2 = new JCheckBoxMenuItem("Check box 2");
    JCheckBoxMenuItem cbmi3 = new JCheckBoxMenuItem("Check box 3");

    // Add the menu items to "Menu 2".  Then add a separator to
    // separate them from the radio buttons that will be added next.
    //
    menu2.add(cbmi1);
    menu2.add(cbmi2);
    menu2.add(cbmi3);
    menu2.addSeparator();

    // Create the radio buttons to be added below the separator on
    // the "Menu 2".
    //
    JRadioButtonMenuItem rbmi1 = new JRadioButtonMenuItem("Radio 1");
    JRadioButtonMenuItem rbmi2 = new JRadioButtonMenuItem("Radio 2");
    JRadioButtonMenuItem rbmi3 = new JRadioButtonMenuItem("Radio 3");

    // Create a button group to enforce single selection of the
    // radio buttons.  And then add the radio buttons to the group.
    //
    ButtonGroup bg = new ButtonGroup();
    bg.add(rbmi1);
    bg.add(rbmi2);
    bg.add(rbmi3);

    // Finally, add the radio buttons to "Menu 2".
    //
    menu2.add(rbmi1);
    menu2.add(rbmi2);
    menu2.add(rbmi3);

    // Create the menu bar; don't forget this step!
    //
    JMenuBar menuBar = new JMenuBar();

    // Add the three top-level menus, "Menu 1", "Menu 2" and "Menu 3"
    // to the menu bar.
    //
    menuBar.add(menu1);
    menuBar.add(menu2);
    menuBar.add(menu3);

    setJMenuBar(menuBar);
  }

  public Dimension getPreferredSize()
  {
    return new Dimension(300, 400);
  }

  public static void main(String [] args)
  {
    Menus app = new Menus();
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    app.addWindowListener(wL);


    app.pack();
    app.setVisible(true);
  }

}
