import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

/**
   This class demonstrates use of the Swing split pane. This demo
   resuses two of the JList components from a previous example.
*/
class SplitPaneDemo extends JPanel
{
  /**
     No-arg constructor.
  */
  public SplitPaneDemo()
  {
    // Construct a JSplitPane object.  Specify a horizontal split.
    //
    JSplitPane splitPane1 = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT);
    splitPane1.setOneTouchExpandable(true);

    // JSplitPane's can take two containers.  Create a JPanel to
    // place in the left split. Set a border on it so you can see
    // its bounds more clearly.
    //
    JPanel left1 = new JPanel();
    left1.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
    left1.add(new JScrollPane(createList1()));
    splitPane1.setLeftComponent(left1);

    // Create a similar panel for the righthand side of the split
    // pane.
    //
    JPanel right1 = new JPanel();
    right1.add(new JScrollPane(createList2()));
    right1.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
    splitPane1.setRightComponent(right1);

    add(splitPane1);
  }

  // Create the list components that will be placed in the two halves
  // of the split pane.  Just reuse two list components from an
  // earlier example.


  // Create the component for the left-hand side of the split pane.
  //
  Component createList1()
  {
    Font f14 = new Font("SansSerif", Font.PLAIN, 14);

    String [] philosophers = {"Aristotle", "Confucius", "Laotze", 
			      "Pascal", "Plato", "Rousseau", 
			      "Socrates", ""};

    String [] mathematicians = {"Abel", "Chebyshev", "Dirichlet", 
				"Fourier", "Lagrange", "Galois", 
				"Gauss", "Laplace", "Landau"};

    JList singleSelectionList = new JList();
    singleSelectionList.setVisibleRowCount(7);
    singleSelectionList.setFont(f14);
    singleSelectionList.setListData(philosophers);

    Box singleSelectionBox = Box.createVerticalBox();

    JLabel singleSelectionLabel = new JLabel("My Favorite Philosophers");
    singleSelectionBox.add(singleSelectionLabel);
    singleSelectionBox.add(Box.createRigidArea(new Dimension(0, 10)));

    JScrollPane scrollPane = new JScrollPane(singleSelectionList);
    scrollPane.setVerticalScrollBarPolicy(
      JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
    singleSelectionBox.add(scrollPane);

    return singleSelectionBox;
  }

  // Create the second component for the right-hand side of the split
  // pane.
  //
  public Component createList2()
  {
    Font f14 = new Font("SansSerif", Font.PLAIN, 14);

    String [] painters = {"Michelangelo", "Rembrandt", "Renoir", 
			  "da Vinci", "van Gogh", "Monet", "Manet",
			  "Picasso"};

    JList singleIntervalList = new JList();
    singleIntervalList.setVisibleRowCount(7);
    singleIntervalList.setFont(f14);
    singleIntervalList.setListData(painters);

    Box singleIntervalBox = Box.createVerticalBox();

    JLabel singleIntervalLabel = new JLabel("My Favorite Artists");
    singleIntervalBox.add(singleIntervalLabel);
    singleIntervalBox.add(Box.createRigidArea(new Dimension(0, 10)));

    JScrollPane scrollPane = new JScrollPane(singleIntervalList);
    singleIntervalBox.add(scrollPane);

    return singleIntervalBox;
  }


  public static void main(String [] args)
  {
    JFrame f = new JFrame("JSplitPane Demo");

    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    SplitPaneDemo app = new SplitPaneDemo();

    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }
}
