import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class ComponentEventDemo extends JPanel 
{
  public ComponentEventDemo()
  {
    label = new JLabel("This label is an event source");

    // Listen for events on our label.
    ComponentMonitor compL = new ComponentMonitor();
    label.addComponentListener(compL);

    // Listen for events on the application panel.
    ContainerMonitor contL = new ContainerMonitor();

    // Listen for mouse clicks on the panel, and
    // toggle the presence of the label in the panel.
    MouseAdapter mL = new MouseAdapter()
      {
	public void mouseClicked(MouseEvent e)
	  {
	    Container cont = (Container) e.getSource();
	    if (cont.getComponentCount() == 0)
	      cont.add(label);
	    else
	      cont.remove(label);
	    repaint();
	  }
      };

    this.addMouseListener(mL);
    this.addContainerListener(contL);

    add(label, BorderLayout.SOUTH);
  }

  public Dimension getPreferredSize()
  {
    return new Dimension(300, 80);
  }

  public static void main(String [] args)
  {
    ComponentEventDemo app = new ComponentEventDemo();

    JFrame f = new JFrame("Component Event Demo");
    WindowListener wl = new WindowAdapter() 
      {
	public void windowClosing(WindowEvent e) 
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wl);
    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }

  JLabel label;
}


class ComponentMonitor implements ComponentListener
{

  public void componentHidden(ComponentEvent e)
  {
    System.out.println("Component hidden.");
  }

  public void componentMoved(ComponentEvent e)
  {
    System.out.println("Component moved.");
  }
  public void componentResized(ComponentEvent e)
  {
    Component c = (Component) e.getSource();
    System.out.println("Component resized: " + c.getSize());
    System.out.println("\tBounds = " + c.getBounds());
    System.out.println("\tLocation = " + c.getLocation());
  }

  public void componentShown(ComponentEvent e)
  {
    System.out.println("Component shown.");

  }

}


class ContainerMonitor implements ContainerListener
{
  public void componentAdded(ContainerEvent e)
  {
    System.out.println("Component added.");
  }

  public void componentRemoved(ContainerEvent e)
  {
    System.out.println("Component removed");
  }
}
